@@ -5,9 +5,19 @@ from usb.core import USBError
 try:
     from pixel_ring import pixel_ring
 
+    class PixelRingState:
+        """Host pixel ring states."""
+
+        off = 0
+        speak = 1
+        think = 2
+
+    pixel_ring.off()
+    ring_state = PixelRingState.off
+
     _mic_is_respeaker = True
-except (USBError, ValueError, FileNotFoundError):
-    print("No ReSpeaker Microphone detected")
+except (USBError, ValueError, FileNotFoundError, PermissionError) as e:
+    print(f"No ReSpeaker Microphone detected or not able to connect: {e}")
     _mic_is_respeaker = False
 
 
@@ -15,12 +25,16 @@ def processing_starts() -> None:
     """Do before NLP starts."""
     if _mic_is_respeaker:
         pixel_ring.speak()
+        global ring_state
+        ring_state = PixelRingState.speak
 
 
 def processing_ends() -> None:
     """Do when NLP ends."""
     if _mic_is_respeaker:
         pixel_ring.off()
+        global ring_state
+        ring_state = PixelRingState.off
 
 
 def tts_starts() -> None:
@@ -32,4 +46,7 @@ def tts_starts() -> None:
 def tts_ends() -> None:
     """Do when voice output ends."""
     if _mic_is_respeaker:
-        pixel_ring.speak()
+        if ring_state == PixelRingState.speak:
+            pixel_ring.speak()
+        else:
+            pixel_ring.off()
