@@ -5,6 +5,10 @@ class AssistantBaseException(Exception):
     """Base assistant exception."""
 
 
+class ConfigValidationError(AssistantBaseException):
+    """Config Validation Error."""
+
+
 class NlpException(AssistantBaseException):
     """Natural Language Processor Error."""
 
