@@ -1,17 +1,30 @@
 """Keyword detector component."""
 
 import struct
-from typing import List
 
 import pvporcupine
 
+from voiceassistant.config import Config
+from voiceassistant.exceptions import ConfigValidationError
+
 
 class KeywordDetector:
     """Keyword detector."""
 
-    def __init__(self, keywords: List) -> None:
+    def __init__(self) -> None:
         """Create Keyword detector object."""
-        self._detector = pvporcupine.create(keywords=keywords)
+        keyword = Config.triggerword.picovoice.word
+
+        if keyword not in pvporcupine.KEYWORDS:
+            raise ConfigValidationError(
+                f"available keywords are {pvporcupine.KEYWORDS}"
+            )
+
+        self._detector = pvporcupine.create(
+            keywords=[keyword],
+            sensitivities=[Config.triggerword.picovoice.sensitivity],
+        )
+
         self.rate = self._detector.sample_rate
         self.chunk_size = self._detector.frame_length
 
